# b3Dv

This package is meant to easily plot functions over 3D surfaces and point clouds.
It is built on top of the [Blender Python API](https://docs.blender.org/api/current/index.html).

## Installation

The project is still in early alpha develpment and is not yet available on PyPI.
It is however available on the test PyPI repository.
To install it, run the following command:

```bash
python3 -m pip install --index-url https://test.pypi.org/simple/ --no-deps b3Dv
```

The installation of dependencies might be necessary.
The following command will install the necessary dependencies:

```bash
python3 -m pip install numpy open3d bpy
```

## Usage

main.py is a simple example of how to use the package.
More documentation is coming soon.
